@@ -10,10 +10,12 @@ AMOUNT_COL = "amount"
 TOKEN_PRICE_COL = "token_price"
 BLOCK_NUM_COL = "block_number"
 BLOCK_TIMESTAMP_COL = "block_timestamp"
+DURATION_LABEL_COL = "duration"
 FLIPSIDE_URL = "https://api-v2.flipsidecrypto.xyz"
 DEFAULT_SOURCE_STORE = "./data/source_save/"
 STORE_SIZE_CHECKPOINT = 41943040
 DEFAULT_SF_KEY = "default"
+TIMESERIES_SF_KEY = "timeseries_feature"
 ADDRESS_SF_KEY = "address"
 VECTOR_SF_KEY = "vector"
 COSINE_SIM_SF_KEY = "cosine_sim"
@@ -24,6 +26,7 @@ TOP_ADDRESS_SF_KEY = "top_address"
 EXCLUSION_SF_KEY = "exclusion"
 TOKEN_PRICE_SF_KEY = "token_price"
 PROFIT_LOSS_SF_KEY = "profit_loss"
+DUPLICATED_SF_KEY = "duplicated"
 SPARK_APP_NAME = "seshat"
 PANDAS_MODE = "df"
 PYSPARK_MODE = "spf"
