@@ -5,7 +5,6 @@ from .base import (
     PercentileTransactionValueDeriver,
     SFrameFromColsDeriver,
     StaticValueColumnAdder,
-    TimeWindowTransformer,
     FractionDeriver,
     ProfitLossDeriver,
     DateTimeTypeDeriver,
@@ -20,6 +19,8 @@ from .base import (
     TokenPriceDeriver,
     TokenSwapTradeDeriver,
     TokenFeatureTransformationDeriver,
+    BranchClassifier,
+    Tagger,
 )
 
 from .from_database import FromSQLDBDeriver
